package com.biganto.visual.roompark.data.repository.api

import com.biganto.visual.roompark.data.repository.api.retrofit.DEFAULT_ARTICLE_PAGE_SIZE
import com.biganto.visual.roompark.data.repository.api.retrofit.PlanTypeCatalog
import com.biganto.visual.roompark.data.repository.api.retrofit.raw.*
import io.reactivex.Observable

/**
 * Created by Vladislav Bogdashkin on 29.10.2019.
 */

interface IRoomParkApi {


    fun authenticate(login: String, pwd: String): Observable<AuthRaw>
    fun subscribeTopic(
        userToken: String,
        deviceToken: String,
        topicName: String
    ): Observable<StatusResponse>

    fun unSuubscribeTopic(
        userToken: String,
        deviceToken: String,
        topicName: String
    ): Observable<StatusResponse>

    fun getDeals(userToken: String): Observable<List<DealRaw>>
    fun getFavorites(userToken: String): Observable<List<EstateRaw>>
    fun getFeeds(userToken: String): Observable<List<FeedRaw>>
    fun getArticle(id: Int): Observable<ArticleRaw>
    fun getPhotos(parentId: Int): Observable<List<NewsPhotoRaw>>
    fun getEstatePlanTypes(estateId: Int): Observable<List<PlanTypeRaw>>
    fun getDirectPlan(
        estateId: Int,
        planType: PlanTypeCatalog,
        showFurniture: Boolean,
        showSizes: Boolean,
        showWalls: Boolean,
        showElectric: Boolean
    ): Observable<List<String>>

    fun getMultiTour(building: Int, flat: Int): Observable<List<PlanRaw>>
    fun getArticlesPage(feedName:String,
                        pageSize:Int = DEFAULT_ARTICLE_PAGE_SIZE,
                        page:Int): Observable<ArticlesListPaginationRaw>

    fun getAlbums(parentId: Int? = null): Observable<List<ImageAlbumRaw>>
}


interface IBigantoApi {
}