package com.biganto.visual.roompark.domain.interactor

import com.biganto.visual.roompark.domain.model.*
import io.reactivex.Single
import java.util.*
import javax.inject.Inject

/**
 * Created by Vladislav Bogdashkin on 09.10.2019.
 */

class FeedsInteractor @Inject constructor(
) {

    fun fetchTopFeeds(): Single<FeedsHeaderModel> = Single.just(testFeeds)

    fun fetchArticles(feedId: Int): Single<ArticlesPreviewModel> = Single.just(
        when (feedId) {
            1 -> testNewsArticles
            2 -> testBlogsArticles
            3 -> testDevArticles
            else -> error("unknown feedId")
        }
    )

    fun fetchAlbums(): Single<List<AlbumPreviewModel>> = Single.just(albumsPreviews)

    fun fetchCams(): Single<WebCamListModel> = Single.just(camsList)


    companion object {

        private const val sampleUrl: String =
            "https://room-park.ru/assets/news_articles/preview/00/00/00/109-8c9b72.jpeg"
        private const val sampleUrlB =
            "https://room-park.ru/assets/news_articles/preview/00/00/00/104-2b4eff.jpeg"
        private const val sampleUrlDev =
            "https://room-park.ru/assets/news_articles/preview/00/00/00/96-a972cd.jpeg"

        val testFeeds = FeedsHeaderModel(
            listOf(
                FeedModel(1, "НОВОСТИ"),
                FeedModel(2, "БЛОГИ"),
                FeedModel(2, "БЛОГ СТРОИТЕЛЬСТВА")
            )
        )

        val testNewsArticles = ArticlesPreviewModel(
            1,
            listOf(
                ArticlePreviewModel(
                    1
                    , Date()
                    , "Первая новость"
                    , "Самый очаровательной анонс в мире"
                    , sampleUrl
                    , false
                ),
                ArticlePreviewModel(
                    1
                    , Date()
                    , "Первая новость"
                    , "Самый очаровательной анонс в мире"
                    , sampleUrl
                    , false
                ),
                ArticlePreviewModel(
                    1
                    , Date()
                    , "Первая новость"
                    , "Самый очаровательной анонс в мире"
                    , sampleUrl
                    , false
                )
            )
        )

        val testBlogsArticles = ArticlesPreviewModel(
            2,
            listOf(
                ArticlePreviewModel(
                    1
                    , Date()
                    , "Первая новость"
                    , "Самый очаровательной анонс в мире"
                    , sampleUrlB
                    , false
                ),
                ArticlePreviewModel(
                    1
                    , Date()
                    , "НОВЫЙ ОФИС ПРОДАЖ ЖК «РУМЯНЦЕВО-ПАРК»"
                    , "Самый очаровательной анонс в мире"
                    , sampleUrlB
                    , false
                ),
                ArticlePreviewModel(
                    1
                    , Date()
                    , "В «РУМЯНЦЕВО-ПАРК» ПРИСТУПИЛИ К МОНТАЖУ ОКОННЫХ БЛОКОВ"
                    , "Самый очаровательной анонс в мире"
                    , sampleUrlB
                    , false
                )
            )
        )

        val testDevArticles = ArticlesPreviewModel(
            3,
            listOf(
                ArticlePreviewModel(
                    1
                    , Date()
                    , "Ход1"
                    , "Самый очаровательной анонс в мире"
                    , sampleUrlDev
                    , false
                ),
                ArticlePreviewModel(
                    1
                    , Date()
                    , "Ход2"
                    , "Самый очаровательной анонс в мире"
                    , sampleUrlDev
                    , false
                ),
                ArticlePreviewModel(
                    1
                    , Date()
                    , "Ход3"
                    , "Самый очаровательной анонс в мире"
                    , sampleUrlDev
                    , false
                )
            )
        )

        val albumsPreviews = listOf<AlbumPreviewModel>(
            AlbumPreviewModel(
                1,
                2,
                Date(3131231L),
                "Dom 1",
                "https://room-park.ru/assets/gallery_images/image_2600/00/00/02/764-1d9795.png",
                false
            ),
            AlbumPreviewModel(
                1,
                2,
                Date(31312323421L),
                "Dom 1",
                "https://room-park.ru/assets/gallery_images/image_2600/00/00/02/626-8afd4a.jpeg",
                false
            ),
            AlbumPreviewModel(
                1,
                2,
                Date(3131232131L),
                "Dom 1",
                "https://room-park.ru/assets/gallery_images/image_2600/00/00/02/573-1fa95c.jpeg",
                false
            )
        )

        val camsList = WebCamListModel(arrayListOf(
            WebCamModel(
                "Камера Дом №1",
                1,
                "blob:https://room-park.ru/fd579683-4bda-4f87-8663-dfe6c02af2f1"
            ),
            WebCamModel(
                "Камера Дом №2",
                2,
                "blob:https://room-park.ru/58956693-f36d-4f8a-bc89-9bded955dfdd"
            ),
            WebCamModel(
                "Камера Дом №3",
                3,
                "blob:https://room-park.ru/19d41d5a-565b-4fc9-a72f-06fbe87e8fb6"
            )
        ))
    }
}



